library template_cache.transformer.writer;

import 'dart:async';
import 'package:barback/barback.dart';
import 'package:template_cache_transformer/src/generator.dart';


/// Pub transformer which gets template cache generated by
/// [TemplateCacheGenerator] and writes its content into an HTML page specified
/// as the application's entry point, right before closing `</head>` tag.
class TemplateCacheWriter extends Transformer {
  final AssetId _entryPointId;

  // TODO: user shouldn't specify asset ID format in the pubspec.yaml. Figure
  // out how to pass `package` to [AssetId] constructor.
  TemplateCacheWriter(String entryPoint)
      : _entryPointId = new AssetId.parse(entryPoint);

  @override
  isPrimary(AssetId id) => _entryPointId == id;

  @override
  apply(Transform transform) {
    // TODO: entry point's package can differ from template cache's package.
    var templateCacheId = new AssetId(_entryPointId.package,
        TemplateCacheGenerator.CACHE_PATH);

    return Future.wait([
      transform.readInputAsString(_entryPointId),
      transform.readInputAsString(templateCacheId)
    ]).then((results) {
      transform.logger.info('Writing template cache into "$_entryPointId"');
      transform.addOutput(new Asset.fromString(_entryPointId,
          results[0].replaceFirst(r'</head>', '${results[1]}</head>')));
    });
  }
}
